@@ -1,3 +1,4 @@
+from .factory import generator_factory
 from .generators import (
     ChaseModeDmxDataGenerator,
     DmxData,
@@ -12,6 +13,7 @@ from .mode import Mode
 from .types import DmxDataGenerator
 
 __all__ = (
+    "generator_factory",
     "Mode",
     "DmxData",
     "DmxDataGenerator",
