@@ -1,3 +1,4 @@
+from .cli import Cli, Command, CommandGroup, Group, MutualExclusiveGroup, Option
 from .feedback import Feedback
 from .formatters import CustomHelpFormatter
 from .progress_bar import ProgressBar
@@ -5,8 +6,14 @@ from .reports import generate_settings_report
 from .table_logger import TableLogger
 
 __all__ = (
+    "Cli",
+    "Command",
+    "CommandGroup",
     "CustomHelpFormatter",
     "Feedback",
+    "Group",
+    "MutualExclusiveGroup",
+    "Option",
     "ProgressBar",
     "TableLogger",
     "generate_settings_report",
